buffet: Remove 'chromeos' namespace and move everything to buffet NS

As discussed, moved all the classes out of chromeos namespace into
'buffet.

Also fixed a number of cpplint's warnings.

BUG=None
TEST=Everything still compiles and unit tests succeed.

Change-Id: Ide864acb2504627404966727f66d353af60e531d
Reviewed-on: https://chromium-review.googlesource.com/198971
Reviewed-by: Christopher Wiley <wiley@chromium.org>
Commit-Queue: Alex Vakulenko <avakulenko@chromium.org>
Tested-by: Alex Vakulenko <avakulenko@chromium.org>
diff --git a/buffet/data_encoding.h b/buffet/data_encoding.h
index b7223bd..e493e36 100644
--- a/buffet/data_encoding.h
+++ b/buffet/data_encoding.h
@@ -2,13 +2,14 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef BUFFET_DATA_ENCODING__H_
-#define BUFFET_DATA_ENCODING__H_
+#ifndef BUFFET_DATA_ENCODING_H_
+#define BUFFET_DATA_ENCODING_H_
 
-#include <vector>
 #include <string>
+#include <utility>
+#include <vector>
 
-namespace chromeos {
+namespace buffet {
 namespace data_encoding {
 
 typedef std::vector<std::pair<std::string, std::string>> WebParamList;
@@ -39,7 +40,7 @@
 // content encoding.
 WebParamList WebParamsDecode(const std::string& data);
 
-} // namespace data_encoding
-} // namespace chromeos
+}  // namespace data_encoding
+}  // namespace buffet
 
-#endif // BUFFET_DATA_ENCODING__H_
+#endif  // BUFFET_DATA_ENCODING_H_